@@ -5,9 +5,9 @@ import shutil
 
 
 def cmd_delete_data():
-  print("deleting all user data")
   d = user_data_dir('Uniton')
   shutil.rmtree(d, ignore_errors=True)
+  print("Deleted all Uniton user data")
 
 def cmd_open_data_dir():
   os.system(f"open '{user_data_dir('Uniton')}'")
