@@ -88,6 +88,18 @@ class Temple(ExampleEnv):
     
 
 
-
+class FloodedGrounds(ExampleEnv):
+  class darwin:
+    url = f"https://github.com/uniton-dev/uniton/releases/download/v{BIN_VERSION}/floodedgrounds_mac.zip"
+    path = join(CACHE_DIR, "floodedgrounds.app")
+    bin = join(CACHE_DIR, "floodedgrounds.app", "Contents", "MacOS", "Floodedgrounds")
+  class linux:
+    url = f"https://github.com/uniton-dev/uniton/releases/download/v{BIN_VERSION}/floodedgrounds_linux.zip"
+    path = join(CACHE_DIR, "floodedgrounds")
+    bin = join(CACHE_DIR, "floodedgrounds", "Floodedgrounds.x86_64")
+  class win32:
+    url = f"https://github.com/uniton-dev/uniton/releases/download/v{BIN_VERSION}/floodedgrounds_windows.zip"
+    path = join(CACHE_DIR, "floodedgrounds")
+    bin = join(CACHE_DIR, "floodedgrounds", "floodedgrounds", "Floodedgrounds.exe")
 
 
